.rss_feed {
    width: 300px;
}
.rss_item_list {
    padding-left: 0;
    margin-left: 0;
    border-bottom: 1px solid gray;
}

.rss_item_list li {
    list-style: none;
    margin: 0;
    padding: 0.25em;
    border-top: 1px solid gray;
}

.rss_item_desc { 
    display: none;
}

.rss_item_list li a {
    text-decoration: none;
}

